@@ -844,6 +844,8 @@ MagickExport Image *ReadImage(const ImageInfo *image_info,
     image=next;
   }
   read_info=DestroyImageInfo(read_info);
+  if (GetBlobError(image) != MagickFalse)
+    ThrowReaderException(CorruptImageError,"UnableToReadImageData");
   return(GetFirstImageInList(image));
 }
 
@@ -1104,13 +1106,13 @@ MagickExport MagickBooleanType WriteImage(const ImageInfo *image_info,
   if (sans_exception->severity == PolicyError)
     magick_info=GetMagickInfo(write_info->magick,exception);
   sans_exception=DestroyExceptionInfo(sans_exception);
-  if (magick_info != (const MagickInfo *) NULL)
+  if ((magick_info != (const MagickInfo *) NULL) &&
+      (GetMagickRawSupport(magick_info) != MagickFalse))
     {
       if (GetMagickEndianSupport(magick_info) == MagickFalse)
         image->endian=UndefinedEndian;
       else
-        if ((image_info->endian == UndefinedEndian) &&
-            (GetMagickRawSupport(magick_info) != MagickFalse))
+        if (image_info->endian == UndefinedEndian)
           {
             unsigned long
               lsb_first;
@@ -1277,6 +1279,8 @@ MagickExport MagickBooleanType WriteImage(const ImageInfo *image_info,
       (write_info->verbose != MagickFalse))
     (void) IdentifyImage(image,stdout,MagickFalse,exception);
   write_info=DestroyImageInfo(write_info);
+  if (GetBlobError(image) != MagickFalse)
+    ThrowWriterException(FileOpenError,"UnableToWriteFile");
   return(status);
 }
 
